@@ -1,8 +1,9 @@
 package Data::Dumper::Table;
 
+use strict;
+use warnings;
 use 5.018;
 use utf8;
-no diagnostics;
 
 use Scalar::Util qw( reftype refaddr blessed );
 use Text::Table;
@@ -10,7 +11,7 @@ use Text::Table;
 use Exporter qw( import );
 our @EXPORT = qw( Tabulate );
 
-our $VERSION = 0.010;
+our $VERSION = '0.011';
 
 our %seen;
 
@@ -27,8 +28,8 @@ sub Tabulate ($) {
 sub _tblize {
     my ($thing, $run) = @_;
     return 'undef()' unless defined $thing;
-    my $r = reftype($thing);
-    my $addr = lc sprintf('%x', refaddr($thing));
+    my $r = reftype($thing) || '';
+    my $addr = lc sprintf('%x', refaddr($thing) || 0);
     my $circular;
     if ($r and defined($seen{ $run }->{ $addr })) {
         $circular++;
@@ -124,7 +125,7 @@ Data::Dumper::Table - A more tabular way to Dumper your Data
 
 =head1 VERSION
 
-Version 0.010
+Version 0.011
 
 =head1 SYNOPSIS
 
